@@ -41,7 +41,7 @@ clearlooks_set_widget_parameters (const GtkWidget      *widget,
                                   GtkStateType          state_type,
                                   WidgetParameters     *params)
 {
-	if (widget && IS_ENTRY (widget))
+	if (widget && GE_IS_ENTRY (widget))
 		state_type = GTK_WIDGET_STATE (widget);
 
 	params->active     = (state_type == GTK_STATE_ACTIVE);
@@ -49,11 +49,11 @@ clearlooks_set_widget_parameters (const GtkWidget      *widget,
 	params->disabled   = (state_type == GTK_STATE_INSENSITIVE);			
 	params->state_type = (ClearlooksStateType)state_type;
 	params->corners    = CL_CORNER_ALL;
-	params->rtl        = !ge_widget_is_ltr ((GtkWidget*)widget);
+	params->ltr        = ge_widget_is_ltr ((GtkWidget*)widget);
 	params->focus      = widget && GTK_WIDGET_HAS_FOCUS (widget);
-	params->is_default = widget && GTK_WIDGET_HAS_DEFAULT (widget);
+	params->is_default = widget && GE_WIDGET_HAS_DEFAULT (widget);
 		
-	if (!params->active && widget && IS_TOGGLE_BUTTON (widget))
+	if (!params->active && widget && GE_IS_TOGGLE_BUTTON (widget))
 		params->active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 		
 	params->xthickness = style->xthickness;
@@ -135,22 +135,28 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 	CHECK_ARGS
 	SANITIZE_SIZE
 
-	if (DETAIL ("entry") && !(widget && widget->parent && IS_TREE_VIEW (widget->parent)))
+	if (DETAIL ("entry") && !(widget && widget->parent && GE_IS_TREE_VIEW (widget->parent)))
 	{
 		WidgetParameters params;
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		
-		if (widget && (ge_is_in_combo_box(widget) || IS_SPIN_BUTTON (widget)))
+		if (widget && (ge_is_in_combo_box(widget) || GE_IS_SPIN_BUTTON (widget)))
 		{
 			width += style->xthickness;
-			params.corners = CL_CORNER_TOPLEFT | CL_CORNER_BOTTOMLEFT;
+			if (!params.ltr)
+				x -= style->xthickness;
+			
+			if (params.ltr)
+				params.corners = CL_CORNER_TOPLEFT | CL_CORNER_BOTTOMLEFT;
+			else
+				params.corners = CL_CORNER_TOPRIGHT | CL_CORNER_BOTTOMRIGHT;
 		}
 		
 		clearlooks_draw_entry (cr, &clearlooks_style->colors, &params,
 		                       x, y, width, height);
 	}
-	else if (DETAIL ("frame") && widget && IS_STATUS_BAR (widget->parent))
+	else if (DETAIL ("frame") && widget && GE_IS_STATUSBAR (widget->parent))
 	{
 		WidgetParameters params;
 		
@@ -193,7 +199,6 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 		frame.shadow = CL_SHADOW_NONE;
 		frame.gap_x  = -1;
 		frame.border = &colors->shade[5];
-		//printf("draw_shadow: %s %s\n", detail, widget? G_OBJECT_TYPE_NAME (widget) : "null");
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		params.corners = CL_CORNER_NONE;
 		
@@ -235,8 +240,8 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 	}
 	else
 	{
-		if (widget)
-			printf("box_gap: %s %s\n", detail, G_OBJECT_TYPE_NAME (widget));
+		/* if (widget)
+			printf("box_gap: %s %s\n", detail, G_OBJECT_TYPE_NAME (widget)); */
 		clearlooks_parent_class->draw_box_gap (style, window, state_type, shadow_type,
 									   area, widget, detail,
 									   x, y, width, height,
@@ -274,7 +279,7 @@ clearlooks_style_draw_extension (DRAW_ARGS, GtkPositionType gap_side)
 	}
 	else
 	{
-		printf("draw_extension: %s\n", detail);
+		/* printf("draw_extension: %s\n", detail); */
 		clearlooks_parent_class->draw_extension (style, window, state_type, shadow_type, area,
 		                              widget, detail, x, y, width, height,
 		                              gap_side);
@@ -297,7 +302,7 @@ clearlooks_style_draw_handle (DRAW_ARGS, GtkOrientation orientation)
 	
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
-	// Evil hack to work around broken orientation for toolbars
+	/* Evil hack to work around broken orientation for toolbars */
 	is_horizontal = (width > height);
 	
 	if (DETAIL ("handlebox"))
@@ -309,8 +314,8 @@ clearlooks_style_draw_handle (DRAW_ARGS, GtkOrientation orientation)
 		handle.type = CL_HANDLE_TOOLBAR;
 		handle.horizontal = is_horizontal;
 		
-		// Is this ever true? -Daniel
-		if (IS_TOOLBAR (widget) && shadow_type != GTK_SHADOW_NONE)
+		/* Is this ever true? -Daniel */
+		if (GE_IS_TOOLBAR (widget) && shadow_type != GTK_SHADOW_NONE)
 		{
 			cairo_save (cr);
 			clearlooks_draw_toolbar (cr, colors, &params, x, y, width, height);
@@ -334,7 +339,6 @@ clearlooks_style_draw_handle (DRAW_ARGS, GtkOrientation orientation)
 	}
 	else
 	{
-//		printf ("draw_handle: %s %s\n", detail, widget ? G_OBJECT_TYPE_NAME (widget) : "null");
 		WidgetParameters params;
 		HandleParameters handle;
 
@@ -342,8 +346,8 @@ clearlooks_style_draw_handle (DRAW_ARGS, GtkOrientation orientation)
 		handle.type = CL_HANDLE_TOOLBAR;
 		handle.horizontal = is_horizontal;
 		
-		// Is this ever true? -Daniel
-		if (IS_TOOLBAR (widget) && shadow_type != GTK_SHADOW_NONE)
+		/* Is this ever true? -Daniel */
+		if (GE_IS_TOOLBAR (widget) && shadow_type != GTK_SHADOW_NONE)
 		{
 			cairo_save (cr);
 			clearlooks_draw_toolbar (cr, colors, &params, x, y, width, height);
@@ -391,8 +395,8 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		                         x, y, width, height);
 	}
 	else if (DETAIL ("button") && widget && widget->parent &&
-                 (IS_TREE_VIEW(widget->parent) ||
-                  IS_CLIST (widget->parent)))
+                 (GE_IS_TREE_VIEW(widget->parent) ||
+                  GE_IS_CLIST (widget->parent)))
 	{
 		WidgetParameters params;
 		ListViewHeaderParameters header;
@@ -400,17 +404,21 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		gint columns, column_index;
 		gboolean resizable = TRUE;
 		
+		/* XXX: make unknown treeview header CL_ORDER_MIDDLE */
+		columns = 3;
+		column_index = 1;
+		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		
 		params.corners = CL_CORNER_NONE;
 		
-		if (IS_TREE_VIEW (widget->parent))
+		if (GE_IS_TREE_VIEW (widget->parent))
 		{
 			clearlooks_treeview_get_header_index (GTK_TREE_VIEW(widget->parent),
 										   widget, &column_index, &columns,
 										   &resizable);
 		}
-		else if (IS_CLIST (widget->parent))
+		else if (GE_IS_CLIST (widget->parent))
 		{
 			clearlooks_clist_get_header_index (GTK_CLIST(widget->parent),
 										widget, &column_index, &columns);
@@ -419,9 +427,9 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		header.resizable = resizable;
 		
 		if (column_index == 0)
-			header.order = CL_ORDER_FIRST;
+			header.order = params.ltr ? CL_ORDER_FIRST : CL_ORDER_LAST;
 		else if (column_index == columns-1)
-			header.order = CL_ORDER_LAST;
+			header.order = params.ltr ? CL_ORDER_LAST : CL_ORDER_FIRST;
 		else
 			header.order = CL_ORDER_MIDDLE;
 		
@@ -437,7 +445,10 @@ clearlooks_style_draw_box (DRAW_ARGS)
 
 		if (ge_is_in_combo_box(widget))
 		{
-			params.corners = CL_CORNER_TOPRIGHT | CL_CORNER_BOTTOMRIGHT;
+			if (params.ltr)
+				params.corners = CL_CORNER_TOPRIGHT | CL_CORNER_BOTTOMRIGHT;
+			else
+				params.corners = CL_CORNER_TOPLEFT | CL_CORNER_BOTTOMLEFT;
 			
 			/* Seriously, why can't non-gtk-apps at least try to be decent citizens?
 			   Take this fscking OpenOffice.org 1.9 for example. The morons responsible
@@ -449,19 +460,20 @@ clearlooks_style_draw_box (DRAW_ARGS)
 */
 			if (params.xthickness > 2)
 			{
-				x--;
+				if (params.ltr)
+					x--;
 				width++;
 			}			
 		}
 		else
 			params.corners    = CL_CORNER_ALL;		
 	
-		if (IS_TOGGLE_BUTTON (widget) &&
+		if (GE_IS_TOGGLE_BUTTON (widget) &&
 		    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
 			params.active = TRUE;
 		
-		// Fix some firefox crap.
-		if (IS_BUTTON (widget) && IS_FIXED (widget->parent) && widget->allocation.x == -1 &&  widget->allocation.y == -1)
+		/* Fix some firefox crap. */
+		if (GE_IS_BUTTON (widget) && GE_IS_FIXED (widget->parent) && widget->allocation.x == -1 &&  widget->allocation.y == -1)
 		{
 			gtk_style_apply_default_background (widget->parent->style, window, TRUE, GTK_STATE_NORMAL,
 			                                    area, x, y, width, height);
@@ -470,42 +482,37 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		clearlooks_draw_button (cr, &clearlooks_style->colors, &params,
 		                        x, y, width, height);
 	}
-	else if (DETAIL ("spinbutton_up"))
+	else if (DETAIL ("spinbutton_up") || DETAIL ("spinbutton_down"))
 	{
 		if (state_type == GTK_STATE_ACTIVE)
 		{
 			WidgetParameters params;
+			clearlooks_set_widget_parameters (widget, style, state_type, &params);
 			
-			if (style->xthickness ==3)
+			if (style->xthickness == 3)
 			{
-				x--;
 				width++;
+				if (params.ltr)
+					x--;
 			}
-			height+=2;
 			
-			params.state_type = (ClearlooksStateType)state_type;
-			
-			params.corners = CL_CORNER_TOPRIGHT;
-			clearlooks_draw_spinbutton_down (cr, &clearlooks_style->colors, &params,
-											 x, y, width, height);
-		}
-	}
-	else if (DETAIL ("spinbutton_down"))
-	{
-		if (state_type == GTK_STATE_ACTIVE)
-		{
-			WidgetParameters params;
-			params.state_type = (ClearlooksStateType)state_type;
-			
-			params.corners = CL_CORNER_BOTTOMRIGHT;
-			
-			if (style->xthickness ==3)
+			if (DETAIL ("spinbutton_up"))
 			{
-				x--;
-				width++;
+				height+=2;
+				if (params.ltr)
+					params.corners = CL_CORNER_TOPRIGHT;
+				else
+					params.corners = CL_CORNER_TOPLEFT;
 			}
-			clearlooks_draw_spinbutton_down (cr, &clearlooks_style->colors, &params,
-											 x, y, width, height);
+			else
+			{
+				if (params.ltr)
+					params.corners = CL_CORNER_BOTTOMRIGHT;
+				else
+					params.corners = CL_CORNER_BOTTOMLEFT;
+			}
+				
+			clearlooks_draw_spinbutton_down (cr, &clearlooks_style->colors, &params, x, y, width, height);
 		}
 	}
 	else if (DETAIL ("spinbutton"))
@@ -514,18 +521,22 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		
-		params.corners = CL_CORNER_TOPRIGHT | CL_CORNER_BOTTOMRIGHT;
+		if (params.ltr)
+			params.corners = CL_CORNER_TOPRIGHT | CL_CORNER_BOTTOMRIGHT;
+		else
+			params.corners = CL_CORNER_TOPLEFT | CL_CORNER_BOTTOMLEFT;
 		
 		if (style->xthickness == 3)
 		{
-			x--;
+			if (params.ltr)
+				x--;
 			width++;
 		}
 		
 		clearlooks_draw_spinbutton (cr, &clearlooks_style->colors, &params,
 		                            x, y, width, height);
 	}
-	else if (DETAIL ("trough") && widget && IS_SCALE (widget))
+	else if (DETAIL ("trough") && widget && GE_IS_SCALE (widget))
 	{
 		GtkAdjustment *adjustment = gtk_range_get_adjustment (GTK_RANGE (widget));	
 		WidgetParameters params;
@@ -539,13 +550,13 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		slider.inverted   = gtk_range_get_inverted (GTK_RANGE (widget));
 		slider.horizontal = (GTK_RANGE (widget)->orientation == GTK_ORIENTATION_HORIZONTAL);
 		slider.fill_size  = ((slider.horizontal ? width : height) - slider_length) * (1 / ((adjustment->upper - adjustment->lower) / (adjustment->value - adjustment->lower))) + slider_length / 2;
-		if (slider.horizontal && !ge_widget_is_ltr (widget))
+		if (slider.horizontal && !params.ltr)
 			slider.inverted = !slider.inverted;
 		clearlooks_draw_scale_trough (cr, &clearlooks_style->colors,
 		                              &params, &slider,
 		                              x, y, width, height);
 	}
-	else if (DETAIL ("trough") && widget && IS_PROGRESS_BAR (widget))
+	else if (DETAIL ("trough") && widget && GE_IS_PROGRESS_BAR (widget))
 	{
 		WidgetParameters params;
 		
@@ -554,7 +565,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		clearlooks_draw_progressbar_trough (cr, colors, &params, 
 		                                    x, y, width, height);
 	}
-	else if (DETAIL ("trough") && widget && (IS_VSCROLLBAR (widget) || IS_HSCROLLBAR (widget)))
+	else if (DETAIL ("trough") && widget && (GE_IS_VSCROLLBAR (widget) || GE_IS_HSCROLLBAR (widget)))
 	{
 		WidgetParameters params;
 		ScrollBarParameters scrollbar;
@@ -566,7 +577,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		scrollbar.junction   = clearlooks_scrollbar_get_junction (widget);
 		scrollbar.steppers   = clearlooks_scrollbar_visible_steppers (widget);
 		
-		if (IS_RANGE (widget))
+		if (GE_IS_RANGE (widget))
 			scrollbar.horizontal = GTK_RANGE (widget)->orientation == GTK_ORIENTATION_HORIZONTAL;
 		
 		if (scrollbar.horizontal)
@@ -603,7 +614,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 
-		if (widget && IS_PROGRESS_BAR (widget))
+		if (widget && GE_IS_PROGRESS_BAR (widget))
 		{
 			progressbar.orientation = gtk_progress_bar_get_orientation (GTK_PROGRESS_BAR (widget));
 			progressbar.value = gtk_progress_bar_get_fraction(GTK_PROGRESS_BAR(widget));
@@ -615,8 +626,14 @@ clearlooks_style_draw_box (DRAW_ARGS)
 			progressbar.value = 0;
 			progressbar.pulsing = FALSE;
 		}
-		/* WTF is this doing here?
-		 * cairo_reset_clip (cr); */
+		
+		if (!params.ltr)
+		{
+			if (progressbar.orientation == GTK_PROGRESS_LEFT_TO_RIGHT)
+				progressbar.orientation = GTK_PROGRESS_RIGHT_TO_LEFT;
+			else if (progressbar.orientation == GTK_PROGRESS_RIGHT_TO_LEFT)
+				progressbar.orientation = GTK_PROGRESS_LEFT_TO_RIGHT;
+		}
 		
 		clearlooks_draw_progressbar_fill (cr, colors, &params, &progressbar,
 		                                  x, y, width, height,
@@ -648,21 +665,19 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		ge_option_menu_get_props (widget, &indicator_size, &indicator_spacing);
 		
 		if (ge_widget_is_ltr (widget))
-			optionmenu.linepos = width - (indicator_size.width + indicator_spacing.left + indicator_spacing.right) - style->xthickness;
+			optionmenu.linepos = width - (indicator_size.width + indicator_spacing.left + indicator_spacing.right) - 1;
 		else
-			optionmenu.linepos = (indicator_size.width + indicator_spacing.left + indicator_spacing.right) + style->xthickness;
+			optionmenu.linepos = (indicator_size.width + indicator_spacing.left + indicator_spacing.right) + 1;
 		
 		clearlooks_draw_optionmenu (cr, colors, &params, &optionmenu,
-		                            x, y, width, height);
-		                            
-		
+		                            x, y, width, height);		
 	}
 	else if (DETAIL ("menuitem"))
 	{
 		WidgetParameters params;
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		
-		if (widget && IS_MENU_BAR (widget->parent))
+		if (widget && GE_IS_MENU_BAR (widget->parent))
 		{
 			/*params.corners = CL_CORNER_NONE;
 			params.active = TRUE;
@@ -695,7 +710,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		scrollbar.junction   = clearlooks_scrollbar_get_junction (widget);
 		scrollbar.steppers   = clearlooks_scrollbar_visible_steppers (widget);
 		
-		if (IS_RANGE (widget))
+		if (GE_IS_RANGE (widget))
 			scrollbar.horizontal = GTK_RANGE (widget)->orientation == GTK_ORIENTATION_HORIZONTAL;
 		
 		if (clearlooks_style->has_scrollbar_color)
@@ -712,7 +727,12 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		else
 		{
 			ScrollBarStepperParameters stepper;
-			GdkRectangle this_rectangle = { x, y, width, height };
+			GdkRectangle this_rectangle;
+			
+			this_rectangle.x = x;
+			this_rectangle.y = y;
+			this_rectangle.width = width;
+			this_rectangle.height = height;
 
 			stepper.stepper = clearlooks_scrollbar_get_stepper (widget, &this_rectangle);
 
@@ -722,7 +742,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 	}
 	else if (DETAIL ("toolbar") || DETAIL ("handlebox_bin") || DETAIL ("dockitem_bin"))
 	{
-		// Only draw the shadows on horizontal toolbars
+		/* Only draw the shadows on horizontal toolbars */
 		if (shadow_type != GTK_SHADOW_NONE && height < 2*width )
 			clearlooks_draw_toolbar (cr, colors, NULL, x, y, width, height);
 	}
@@ -740,7 +760,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 	}
 	else
 	{
-		//printf("draw_box: %s\n", detail);
+		/* printf("draw_box: %s\n", detail); */
 		clearlooks_parent_class->draw_box (style, window, state_type, shadow_type, area,
 		                        widget, detail, x, y, width, height);
 	}
@@ -774,8 +794,8 @@ clearlooks_style_draw_option (DRAW_ARGS)
 	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
 	cairo_pattern_t *pt;
 
-	inconsistent = (IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)));
-	inconsistent |= (GTK_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent(widget));
+	inconsistent = (GE_IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)));
+	inconsistent |= (GE_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent(widget));
 	inconsistent |= (CHECK_DETAIL(detail, "cellradio") && (shadow_type == GTK_SHADOW_ETCHED_IN));
 
 	draw_bullet |= inconsistent;
@@ -787,8 +807,8 @@ clearlooks_style_draw_option (DRAW_ARGS)
 
 	if (state_type == GTK_STATE_INSENSITIVE)
 	{
-		border = &clearlooks_style->colors.shade[2];
-		dot    = &clearlooks_style->colors.shade[2];
+		border = &clearlooks_style->colors.shade[5];
+		dot    = &clearlooks_style->colors.shade[6];
 	}
 	else
 	{
@@ -824,7 +844,7 @@ clearlooks_style_draw_option (DRAW_ARGS)
 	cairo_stroke (cr);
 	
 #ifdef HAVE_ANIMATION
-	if (clearlooks_style->animation && IS_CHECK_BUTTON (widget) &&
+	if (clearlooks_style->animation && GE_IS_CHECK_BUTTON (widget) &&
         clearlooks_animation_is_animated (widget) &&
         !gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (widget)))
 	{
@@ -844,8 +864,6 @@ clearlooks_style_draw_option (DRAW_ARGS)
 	{
 		if (inconsistent)
 		{
-			cairo_pattern_t *pt;
-
 			cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
 			cairo_set_line_width (cr, 4);
 
@@ -859,12 +877,12 @@ clearlooks_style_draw_option (DRAW_ARGS)
 		else
 		{
 			cairo_arc (cr, 7, 7, 3, 0, M_PI*2);
-			//cairo_set_source_rgb (cr, dot->r, dot->g, dot->b);
+			/* cairo_set_source_rgb (cr, dot->r, dot->g, dot->b); */
 			cairo_set_source_rgba (cr, dot->r, dot->g, dot->b,trans);
 			cairo_fill (cr);
 		
 			cairo_arc (cr, 6, 6, 1, 0, M_PI*2);
-			//cairo_set_source_rgba (cr, 1,1,1, 0.5);
+			/* cairo_set_source_rgba (cr, 1,1,1, 0.5); */
 			cairo_set_source_rgba (cr, 1,1,1, 0.5+trans);		
 			cairo_fill (cr);
 		}
@@ -885,8 +903,8 @@ clearlooks_style_draw_check (DRAW_ARGS)
 	cairo_t *cr;
 	cairo_pattern_t *pt;
 
-	inconsistent = (IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)));
-	inconsistent |= (GTK_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent(widget));
+	inconsistent = (GE_IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)));
+	inconsistent |= (GE_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent(widget));
 	inconsistent |= (CHECK_DETAIL(detail, "cellcheck") && (shadow_type == GTK_SHADOW_ETCHED_IN));
 
 	draw_bullet |= inconsistent;
@@ -901,8 +919,8 @@ clearlooks_style_draw_check (DRAW_ARGS)
 	
 	if (state_type == GTK_STATE_INSENSITIVE)
 	{
-		border = &clearlooks_style->colors.shade[2];
-		dot    = &clearlooks_style->colors.shade[2];
+		border = &clearlooks_style->colors.shade[5];
+		dot    = &clearlooks_style->colors.shade[6];
 	}
 	else
 	{
@@ -946,7 +964,7 @@ clearlooks_style_draw_check (DRAW_ARGS)
 	cairo_stroke (cr);
 		
 #ifdef HAVE_ANIMATION
-	if (clearlooks_style->animation && IS_CHECK_BUTTON (widget) &&
+	if (clearlooks_style->animation && GE_IS_CHECK_BUTTON (widget) &&
 	    clearlooks_animation_is_animated(widget) &&
 	    !gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (widget)))
 	{
@@ -989,20 +1007,30 @@ clearlooks_style_draw_check (DRAW_ARGS)
 static void
 clearlooks_style_draw_tab (DRAW_ARGS)
 {
-	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
-	ClearlooksColors *colors = &clearlooks_style->colors;	
-	WidgetParameters params;
-	ArrowParameters  arrow;
-	
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
-	
-	clearlooks_set_widget_parameters (widget, style, state_type, &params);
-	arrow.type      = CL_ARROW_COMBO;
-	arrow.direction = CL_DIRECTION_DOWN;
-	
-	clearlooks_draw_arrow (cr, colors, &params, &arrow, x, y, width, height);
+	GtkRequisition indicator_size;
+	GtkBorder indicator_spacing;
+	gint arrow_height;
 
-	cairo_destroy (cr);
+	ge_option_menu_get_props (widget, &indicator_size, &indicator_spacing);
+	
+	indicator_size.width += (indicator_size.width % 2) - 1;
+	arrow_height = indicator_size.width / 2;
+	
+	x += (width - indicator_size.width) / 2;
+	y += height/2;
+
+
+	gtk_paint_arrow (style, window,
+	                 state_type, shadow_type,
+	                 area, widget, "arrow",
+	                 GTK_ARROW_UP, TRUE,
+	                 x, y-arrow_height-1, indicator_size.width, arrow_height);
+	                 
+	gtk_paint_arrow (style, window,
+	                 state_type, shadow_type,
+	                 area, widget, "arrow",
+	                 GTK_ARROW_DOWN, TRUE,
+	                 x, y+2, indicator_size.width, arrow_height);
 }
 
 static void
@@ -1039,22 +1067,14 @@ clearlooks_style_draw_hline                      (GtkStyle               *style,
                                  gint                    y)
 {
 	cairo_t *cr;
-
+	SeparatorParameters separator;
+	
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
-	if (DETAIL ("label")) /* wtf? */
-	{
-		printf("draw_vline: label. ermm....?\n");
-	}
-	else
-	{
-		SeparatorParameters separator;
-		
-		separator.horizontal = TRUE;
-		
-		clearlooks_draw_separator (cr, NULL, NULL, &separator,
-		                           x1, y, x2-x1, 2);
-	}
+	separator.horizontal = TRUE;
+	
+	clearlooks_draw_separator (cr, NULL, NULL, &separator,
+	                           x1, y, x2-x1, 2);
 	
 	cairo_destroy (cr);
 }
@@ -1125,7 +1145,7 @@ clearlooks_style_draw_resize_grip (GtkStyle       *style,
 	g_return_if_fail (window != NULL);
 
 	if (edge != GDK_WINDOW_EDGE_SOUTH_EAST)
-		return; // sorry... need to work on this :P
+		return; /* sorry... need to work on this :P */
 	
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
@@ -1154,54 +1174,33 @@ clearlooks_style_draw_arrow (GtkStyle  *style,
                        gint           width,
                        gint           height)
 {
-	ClearlooksStyle  *clearlooks_style = CLEARLOOKS_STYLE (style);
-	ClearlooksColors *colors;
-	cairo_t *cr;
-		
-	CHECK_ARGS
-	SANITIZE_SIZE
-
-	if (arrow_type == (GtkArrowType)4)//NONE - new in GTK 2.10
-		return;
-
-	colors = &clearlooks_style->colors;
-
-	cr = ge_gdk_drawable_to_cairo (window, area);
-
-	if (DETAIL ("arrow"))
+	if (DETAIL ("arrow") && ge_is_combo_box (widget, FALSE) && !ge_is_combo_box_entry(widget))
 	{
-		WidgetParameters params;
-		ArrowParameters  arrow;
+#define CL_COMBO_BOX_ARROW_WIDTH 8
+#define CL_COMBO_BOX_ARROW_HEIGHT 5
+
+		x += (width - CL_COMBO_BOX_ARROW_WIDTH) + 1;
+		y += 1;
 		
-		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		arrow.type = CL_ARROW_NORMAL;
-		arrow.direction = (ClearlooksDirection)arrow_type;
+		width  = CL_COMBO_BOX_ARROW_WIDTH;
+		height = CL_COMBO_BOX_ARROW_HEIGHT;
 		
-/*		cairo_rectangle (cr, x, y, width, height);
-		cairo_set_source_rgb (cr, 1, 0, 0);
-		cairo_fill (cr);
-	*/	
-		if (ge_is_combo_box (widget, FALSE) && !ge_is_combo_box_entry (widget))
-		{
-			arrow.type = CL_ARROW_COMBO;
-			y -= 2;
-			height += 4;
-			x += 1;
-		}
-		
-		clearlooks_draw_arrow (cr, colors, &params, &arrow,
-		                       x, y, width, height);
+		clearlooks_parent_class->draw_arrow (style, window, state_type, shadow, area,
+		                          widget, detail, GTK_ARROW_UP, fill,
+		                          x, y-1, width, height);
+
+		clearlooks_parent_class->draw_arrow (style, window, state_type, shadow, area,
+		                          widget, detail, GTK_ARROW_DOWN, fill,
+		                          x, y+height, width, height);
 	}
 	else
 	{
-		//printf("draw_arrow: %s %s\n", detail, widget ? G_OBJECT_TYPE_NAME (widget) : "null");
+		/* printf("draw_arrow: %s %s\n", detail, widget ? G_OBJECT_TYPE_NAME (widget) : "null"); */
 
 		clearlooks_parent_class->draw_arrow (style, window, state_type, shadow, area,
 		                          widget, detail, arrow_type, fill,
 		                          x, y, width, height);
 	}
-	
-	cairo_destroy (cr);
 }
 
 static void
@@ -1209,15 +1208,8 @@ clearlooks_style_init_from_rc (GtkStyle * style,
 			       GtkRcStyle * rc_style)
 {
 	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
-	double shades[] = {1.15, 0.95, 0.896, 0.82, 0.7, 0.665, 0.5, 0.45, 0.4};
-	CairoColor spot_color;
-	CairoColor bg_normal;
-	double contrast;
-	int i;
 	
 	clearlooks_parent_class->init_from_rc (style, rc_style);
-
-	contrast = CLEARLOOKS_RC_STYLE (rc_style)->contrast;
 	
 	clearlooks_style->progressbarstyle  = CLEARLOOKS_RC_STYLE (rc_style)->progressbarstyle;
 	clearlooks_style->menubarstyle      = CLEARLOOKS_RC_STYLE (rc_style)->menubarstyle;
@@ -1228,6 +1220,21 @@ clearlooks_style_init_from_rc (GtkStyle * style,
 	
 	if (clearlooks_style->has_scrollbar_color)
 		clearlooks_style->scrollbar_color = CLEARLOOKS_RC_STYLE (rc_style)->scrollbar_color;
+}
+
+static void
+clearlooks_style_realize (GtkStyle * style)
+{
+	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
+	double shades[] = {1.15, 0.95, 0.896, 0.82, 0.7, 0.665, 0.5, 0.45, 0.4};
+	CairoColor spot_color;
+	CairoColor bg_normal;
+	double contrast;
+	int i;
+	
+	clearlooks_parent_class->realize (style);
+
+	contrast = CLEARLOOKS_RC_STYLE (style->rc_style)->contrast;
 	
 	/* Lighter to darker */
 	ge_gdk_color_to_cairo (&style->bg[GTK_STATE_NORMAL], &bg_normal);
@@ -1273,7 +1280,7 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 	cairo_t *cr;
 	gboolean free_dash_list = FALSE;
 	gint line_width = 1;
-	gint8 *dash_list = "\1\1";
+	gint8 *dash_list = (gint8 *)"\1\1";
 
 	if (widget)
 	{
@@ -1290,7 +1297,7 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 		if (free_dash_list)
 			g_free (dash_list);
 
-		dash_list = "\4\4";
+		dash_list = (gint8 *)"\4\4";
 		free_dash_list = FALSE;
 	}
 
@@ -1311,7 +1318,7 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 
 	if (dash_list[0])
 	{
-		gint n_dashes = strlen (dash_list);
+		gint n_dashes = strlen ((gchar *)dash_list);
 		gdouble *dashes = g_new (gdouble, n_dashes);
 		gdouble total_length = 0;
 		gdouble dash_offset;
@@ -1526,6 +1533,7 @@ clearlooks_style_class_init (ClearlooksStyleClass * klass)
 	clearlooks_parent_class = g_type_class_peek_parent (klass);
 
 	style_class->copy             = clearlooks_style_copy;
+	style_class->realize          = clearlooks_style_realize;
 	style_class->unrealize        = clearlooks_style_unrealize;
 	style_class->init_from_rc     = clearlooks_style_init_from_rc;
 	style_class->draw_handle      = clearlooks_style_draw_handle;
