@@ -290,7 +290,7 @@ hc_draw_extension (GtkStyle       *style,
 		To fake the apearance of overlap on edge aligned tabs
 		increase clip by edge thickness on gap side. 
 	 */
-	if (widget && (GTK_IS_NOTEBOOK (widget)))
+	if (widget && (GE_IS_NOTEBOOK (widget)))
 	{
 		widget_x = (widget->allocation.x + GTK_CONTAINER (widget)->border_width);
 		widget_y = (widget->allocation.y + GTK_CONTAINER (widget)->border_width);
@@ -302,7 +302,7 @@ hc_draw_extension (GtkStyle       *style,
 	{
 		case GTK_POS_TOP:
 			if (GTK_CHECK_VERSION(2,10,0) || 
-				((widget && GTK_IS_NOTEBOOK (widget)) && 
+				((widget && GE_IS_NOTEBOOK (widget)) && 
 				((x==widget_x) || 
 				((x + width) == (widget_x + widget_width)))))
 			{
@@ -320,7 +320,7 @@ hc_draw_extension (GtkStyle       *style,
 
 		case GTK_POS_LEFT:
 			if (GTK_CHECK_VERSION(2,10,0) || 
-				((widget && GTK_IS_NOTEBOOK (widget)) && 
+				((widget && GE_IS_NOTEBOOK (widget)) && 
 				((y==widget_y) || 
 				((y + height) == (widget_y + widget_height)))))
 			{
@@ -435,7 +435,7 @@ hc_draw_box (GtkStyle	*style,
 	/***********************************************/
 
 	/* Add Menu Shell Hack For Menu Bar Item Prelight */
-	if (IS_MENU_SHELL(widget))
+	if (GE_IS_MENU_SHELL(widget))
 	{
 		hc_gtk2_engine_hack_menu_shell_setup_signals(widget);
 	}  
@@ -637,7 +637,7 @@ hc_draw_slider (GtkStyle * style,
 	hc_draw_box (style, window, state_type, shadow_type, area, widget, 
 			detail, x, y, width, height);
 
-	if (IS_SCALE(widget))
+	if (GE_IS_SCALE(widget))
 	{
 		if (orientation == GTK_ORIENTATION_HORIZONTAL)
 		{
@@ -684,19 +684,17 @@ hc_draw_check (GtkStyle      *style,
 	CHECK_ARGS
 	SANITIZE_SIZE
 
-	/*#warning - CHECK IN CELL RENDERER DOES NOT FOLLOW SIZING ALWAYS TO SMALL - FIND WORKAROUND*/
-
-	if (GTK_IS_CELL_RENDERER_TOGGLE(widget) || CHECK_DETAIL(detail, "cellcheck"))
+	/* Bug #351764 */
+	if ((!GTK_CHECK_VERSION(2,12,0)) && 
+			CHECK_DETAIL(detail, "cellcheck"))
 	{
-		x -= 1;
-		y -= 1;
-		width += 2;
-		height += 2;
+		x += (width - HC_STYLE(style)->cell_indicator_size)/2;
+		y += (height - HC_STYLE(style)->cell_indicator_size)/2;
+		width = HC_STYLE(style)->cell_indicator_size;
+		height = HC_STYLE(style)->cell_indicator_size;
 	}
-
-	inconsistent = (IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)));
-	inconsistent |= (GTK_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent (widget));
-	inconsistent |= (CHECK_DETAIL(detail, "cellcheck") && (shadow_type == GTK_SHADOW_ETCHED_IN));
+	
+	inconsistent = ge_toggle_get_inconsistent(widget, detail, shadow_type);
 
 	line_width = ceil(HC_STYLE(style)->edge_thickness/2);
 	cr = ge_gdk_drawable_to_cairo (window, area);
@@ -737,7 +735,7 @@ hc_draw_check (GtkStyle      *style,
 		/* What should the line width be? not the same as border... 
 			but why this?
 		 */
-		line_width = floor(line_width*3.5);//ceil(MIN(width,height)/5);
+		line_width = floor(line_width*3.5); /* ceil(MIN(width,height)/5); */
 
 		/* The X is capped square, 
 				so uh. inset by line_width/2 to center line
@@ -808,13 +806,14 @@ hc_draw_option (GtkStyle      *style,
 	CHECK_ARGS
 	SANITIZE_SIZE
 
-	/*#warning - OPTION IN CELL RENDERER DOES NOT FOLLOW SIZING ALWAYS TO SMALL - FIND WORKAROUND*/
-	if (GTK_IS_CELL_RENDERER_TOGGLE(widget) || CHECK_DETAIL(detail, "cellcheck"))
+	/* Bug #351764 */
+	if ((!GTK_CHECK_VERSION(2,12,0)) && 
+			CHECK_DETAIL(detail, "cellradio"))
 	{
-		x -= 1;
-		y -= 1;
-		width += 2;
-		height += 2;
+		x += (width - HC_STYLE(style)->cell_indicator_size)/2;
+		y += (height - HC_STYLE(style)->cell_indicator_size)/2;
+		width = HC_STYLE(style)->cell_indicator_size;
+		height = HC_STYLE(style)->cell_indicator_size;
 	}
 
 	cr = ge_gdk_drawable_to_cairo (window, area);
@@ -834,9 +833,7 @@ hc_draw_option (GtkStyle      *style,
 	ge_cairo_set_color(cr, &hc_style->color_cube.fg[state_type]);	
 	cairo_stroke (cr);
 
-	inconsistent = (IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)));
-	inconsistent |= (GTK_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent (widget));
-	inconsistent |= (CHECK_DETAIL(detail, "cellcheck") && (shadow_type == GTK_SHADOW_ETCHED_IN));
+	inconsistent = ge_toggle_get_inconsistent(widget, detail, shadow_type);
 
 	if ((shadow_type == GTK_SHADOW_IN) || inconsistent)
 	{
