@@ -391,7 +391,7 @@ mist_style_draw_shadow(GtkStyle *style,
 		shadow_type = GTK_SHADOW_ETCHED_IN;
 	}
 	
-	if (CHECK_DETAIL(detail, "frame") && widget && widget->parent && GTK_IS_STATUSBAR (widget->parent)) {
+	if (CHECK_DETAIL(detail, "frame") && widget && widget->parent && GE_IS_STATUSBAR (widget->parent)) {
 		if (shadow_type != GTK_SHADOW_NONE) {
 			ge_cairo_set_color(cr, &mist_style->color_cube.dark[GTK_STATE_NORMAL]);	
 	
@@ -718,15 +718,15 @@ mist_style_draw_box(GtkStyle *style,
 	} else {
 		/* Make sure stepper and slider outlines "overlap" - taken from
 		 * bluecurve */
-		if (CHECK_DETAIL(detail, "slider") && widget && GTK_IS_RANGE (widget)) {
+		if (CHECK_DETAIL(detail, "slider") && widget && GE_IS_RANGE (widget)) {
 			GtkAdjustment *adj = GTK_RANGE (widget)->adjustment;
 			if (adj->value <= adj->lower &&
 			    (GTK_RANGE (widget)->has_stepper_a ||
 			     GTK_RANGE (widget)->has_stepper_b)) {
-				if (GTK_IS_VSCROLLBAR (widget)) {
+				if (GE_IS_VSCROLLBAR (widget)) {
 					height += 1;
 					y -= 1;
-				} else if (GTK_IS_HSCROLLBAR (widget)) {
+				} else if (GE_IS_HSCROLLBAR (widget)) {
 					width += 1;
 					x -= 1;
 				}
@@ -735,9 +735,9 @@ mist_style_draw_box(GtkStyle *style,
 			if (adj->value >= adj->upper - adj->page_size &&
 			    (GTK_RANGE (widget)->has_stepper_c ||
 			     GTK_RANGE (widget)->has_stepper_d)) {
-				if (GTK_IS_VSCROLLBAR (widget)) {
+				if (GE_IS_VSCROLLBAR (widget)) {
 					height += 1;
-				} else if (GTK_IS_HSCROLLBAR (widget)) {
+				} else if (GE_IS_HSCROLLBAR (widget)) {
 					width += 1;
 				}
 			}
@@ -858,10 +858,10 @@ mist_style_draw_option(GtkStyle *style,
 	cairo_stroke (cr);
 
 	if ((shadow_type == GTK_SHADOW_IN) || 
-		(IS_TOGGLE_BUTTON(widget) && 
+		(GE_IS_TOGGLE_BUTTON(widget) && 
 		TOGGLE_BUTTON(widget)->inconsistent))
 	{
-		if ((IS_TOGGLE_BUTTON(widget) && 
+		if ((GE_IS_TOGGLE_BUTTON(widget) && 
 			TOGGLE_BUTTON(widget)->inconsistent))
 		{
 			/* Rough logic, just make  thickness 1/3 height */
