@@ -80,30 +80,30 @@
 
 #define FUZZY_COMPARE(i, j, fudge) ((i>j)?(i - j <= fudge):(j - i <= fudge))
 
-GdkBitmap * smooth_arc_clip_mask(gint width, gint height) G_GNUC_INTERNAL;
+GE_INTERNAL GdkBitmap * smooth_arc_clip_mask(gint width, gint height);
 #define clip_mask_unref g_object_unref
 
-gboolean sanitize_parameters(GtkStyle * style, GdkWindow * window, gint * width, gint * height) G_GNUC_INTERNAL;
+GE_INTERNAL gboolean sanitize_parameters(GtkStyle * style, GdkWindow * window, gint * width, gint * height);
 
-GtkWidget* get_combo_box_widget_parent (GtkWidget * widget) G_GNUC_INTERNAL;
+GE_INTERNAL GtkWidget* get_combo_box_widget_parent (GtkWidget * widget);
 
 /* Notebook Tab Info */
 
 /*
-GtkWidget * get_notebook_page(GtkWidget * widget) G_GNUC_INTERNAL;
-GtkWidget * get_tab_label(GtkWidget *page, GtkWidget * widget) G_GNUC_INTERNAL;
+GE_INTERNAL GtkWidget * get_notebook_page(GtkWidget * widget);
+GE_INTERNAL GtkWidget * get_tab_label(GtkWidget *page, GtkWidget * widget);
 
-gboolean widget_is_tab_label(GtkWidget *page, GtkWidget * widget) G_GNUC_INTERNAL;
-gboolean tab_label_is_current_page(GtkWidget *page, GtkWidget * widget) G_GNUC_INTERNAL;
+GE_INTERNAL gboolean widget_is_tab_label(GtkWidget *page, GtkWidget * widget);
+GE_INTERNAL gboolean tab_label_is_current_page(GtkWidget *page, GtkWidget * widget);
 */
 /* Arrow Sizing Workarounds */
-void smooth_reverse_engineer_stepper_box(GtkWidget *range, GtkArrowType arrow_type, gint *x, gint *y, gint *width, gint *height) G_GNUC_INTERNAL;
-void smooth_reverse_engineer_spin_button(GtkWidget *widget, GtkArrowType arrow_type, gint *x, gint *y, gint *width, gint *height) G_GNUC_INTERNAL;
+GE_INTERNAL void smooth_reverse_engineer_stepper_box(GtkWidget *range, GtkArrowType arrow_type, gint *x, gint *y, gint *width, gint *height);
+GE_INTERNAL void smooth_reverse_engineer_spin_button(GtkWidget *widget, GtkArrowType arrow_type, gint *x, gint *y, gint *width, gint *height);
 
-void smooth_reverse_engineer_arrow_box(GtkWidget *widget, const gchar * detail, GtkArrowType arrow_type, gint *x, gint *y, gint *width, gint *height) G_GNUC_INTERNAL;
+GE_INTERNAL void smooth_reverse_engineer_arrow_box(GtkWidget *widget, const gchar * detail, GtkArrowType arrow_type, gint *x, gint *y, gint *width, gint *height);
 
-void smooth_gtk_button_get_props (GtkWidget *widget, GtkBorder *default_border, GtkBorder *default_outside_border, gboolean  *interior_focus) G_GNUC_INTERNAL;
-void smooth_gtk_widget_get_focus_props (GtkWidget *widget, gint *focus_line_width, gint *focus_padding, gboolean  *interior_focus) G_GNUC_INTERNAL;
-gboolean smooth_cell_renderer_toggle_get_inconsistent (GtkWidget *widget) G_GNUC_INTERNAL;
+GE_INTERNAL void smooth_gtk_button_get_props (GtkWidget *widget, GtkBorder *default_border, GtkBorder *default_outside_border, gboolean  *interior_focus);
+GE_INTERNAL void smooth_gtk_widget_get_focus_props (GtkWidget *widget, gint *focus_line_width, gint *focus_padding, gboolean  *interior_focus);
+GE_INTERNAL gboolean smooth_cell_renderer_toggle_get_inconsistent (GtkWidget *widget);
 
 #endif /* SMOOTH_GTK2_MISC_H */
