@@ -3,6 +3,7 @@
 #include "general-support.h"
 #include "widget-information.h"
 #include <math.h>
+#include <string.h>
 
 /* Widget Type Lookups/Macros
    
@@ -10,15 +11,16 @@
    Smooth-Engine.
 */ 
 gboolean
-ge_object_is_a (const GtkWidget * widget, const gchar * type_name)
+ge_object_is_a (const GObject * object, const gchar * type_name)
 {
   gboolean result = FALSE;
  
-  if ((widget))
+  if ((object))
     {
       GType tmp = g_type_from_name (type_name);
+
       if (tmp)
-	result = g_type_check_instance_is_a ((GTypeInstance *) widget, tmp);
+	result = g_type_check_instance_is_a ((GTypeInstance *) object, tmp);
     }
  
   return result;
@@ -31,7 +33,7 @@ ge_is_combo_box_entry (GtkWidget * widget)
  
   if ((widget) && (widget->parent))
     {
-      if (IS_COMBO_BOX_ENTRY (widget->parent))
+      if (GE_IS_COMBO_BOX_ENTRY (widget->parent))
 	result = TRUE;
       else
 	result = ge_is_combo_box_entry (widget->parent);
@@ -44,11 +46,11 @@ ge_combo_box_is_using_list (GtkWidget * widget)
 {
   gboolean result = FALSE;
  
-  if ((widget) && (IS_COMBO_BOX (widget->parent)))
+  if ((widget) && (GE_IS_COMBO_BOX (widget->parent)))
     {
       gboolean *tmp = NULL;
  
-      gtk_widget_style_get (widget, "appears-as-list", &result, NULL);
+      gtk_widget_style_get (widget->parent, "appears-as-list", &result, NULL);
  
       if (tmp)
 	result = *tmp;
@@ -64,12 +66,12 @@ ge_is_combo_box (GtkWidget * widget, gboolean as_list)
  
   if ((widget) && (widget->parent))
     {
-      if (IS_COMBO_BOX (widget->parent))
+      if (GE_IS_COMBO_BOX (widget->parent))
         {
           if (as_list)
-            result = (ge_combo_box_is_using_list(widget));
+            result = (ge_combo_box_is_using_list(widget->parent));
           else
-            result = (!ge_combo_box_is_using_list(widget));
+            result = (!ge_combo_box_is_using_list(widget->parent));
         }
       else
 	result = ge_is_combo_box (widget->parent, as_list);
@@ -84,7 +86,7 @@ ge_is_combo (GtkWidget * widget)
  
   if ((widget) && (widget->parent))
     {
-      if (IS_COMBO (widget->parent))
+      if (GE_IS_COMBO (widget->parent))
 	result = TRUE;
       else
 	result = ge_is_combo (widget->parent);
@@ -104,11 +106,11 @@ ge_is_toolbar_item (GtkWidget * widget)
   gboolean result = FALSE;
  
   if ((widget) && (widget->parent)) {
-    if ((IS_BONOBO_TOOLBAR (widget->parent))
-	|| (IS_BONOBO_DOCK_ITEM (widget->parent))
-	|| (IS_EGG_TOOLBAR (widget->parent))
-	|| (IS_TOOLBAR (widget->parent))
-	|| (IS_HANDLE_BOX (widget->parent)))
+    if ((GE_IS_BONOBO_TOOLBAR (widget->parent))
+	|| (GE_IS_BONOBO_DOCK_ITEM (widget->parent))
+	|| (GE_IS_EGG_TOOLBAR (widget->parent))
+	|| (GE_IS_TOOLBAR (widget->parent))
+	|| (GE_IS_HANDLE_BOX (widget->parent)))
       result = TRUE;
     else
       result = ge_is_toolbar_item (widget->parent);
@@ -123,7 +125,7 @@ ge_is_panel_widget_item (GtkWidget * widget)
  
   if ((widget) && (widget->parent))
     {
-      if (IS_PANEL_WIDGET (widget->parent))
+      if (GE_IS_PANEL_WIDGET (widget->parent))
 	result = TRUE;
       else
 	result = ge_is_panel_widget_item (widget->parent);
@@ -138,18 +140,18 @@ ge_is_bonobo_dock_item (GtkWidget * widget)
  
   if ((widget))
     {
-      if (IS_BONOBO_DOCK_ITEM(widget) || IS_BONOBO_DOCK_ITEM (widget->parent))
+      if (GE_IS_BONOBO_DOCK_ITEM(widget) || GE_IS_BONOBO_DOCK_ITEM (widget->parent))
 	result = TRUE;
-      else if (IS_BOX(widget) || IS_BOX(widget->parent))
+      else if (GE_IS_BOX(widget) || GE_IS_BOX(widget->parent))
         {
-          GtkContainer *box = IS_BOX(widget)?GTK_CONTAINER(widget):GTK_CONTAINER(widget->parent);
+          GtkContainer *box = GE_IS_BOX(widget)?GTK_CONTAINER(widget):GTK_CONTAINER(widget->parent);
           GList *children = NULL, *child = NULL;
  
           children = gtk_container_get_children(box);
               
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
-	      if (IS_BONOBO_DOCK_ITEM_GRIP(child->data))
+	      if (GE_IS_BONOBO_DOCK_ITEM_GRIP(child->data))
 	        {
 	          result = TRUE;
 	          child = NULL;
@@ -170,7 +172,7 @@ ge_find_combo_box_entry_widget (GtkWidget * widget)
 
   if (widget)
     {
-      if (IS_COMBO_BOX_ENTRY (widget))
+      if (GE_IS_COMBO_BOX_ENTRY (widget))
 	result = widget;
       else
 	result = ge_find_combo_box_entry_widget (widget->parent);
@@ -186,7 +188,7 @@ ge_find_combo_box_widget (GtkWidget * widget, gboolean as_list)
  
   if (widget)
     {
-      if (IS_COMBO_BOX (widget))
+      if (GE_IS_COMBO_BOX (widget))
         {
           if (as_list)
             result = (ge_combo_box_is_using_list(widget))?widget:NULL;
@@ -206,7 +208,7 @@ ge_find_combo_widget (GtkWidget * widget)
  
   if (widget)
     {
-      if (IS_COMBO (widget))
+      if (GE_IS_COMBO (widget))
 	result = widget;
       else
 	result = ge_find_combo_widget(widget->parent);
@@ -241,6 +243,15 @@ ge_cell_renderer_toggle_get_inconsistent (GtkWidget * widget)
   return result;
 }
 
+gboolean
+ge_toggle_get_inconsistent (GtkWidget * widget, const gchar *detail, GtkShadowType shadow_type)
+{
+	return (GE_IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)))
+				| (GE_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent (widget))
+				| (CHECK_DETAIL(detail, "cellcheck") && (shadow_type == GTK_SHADOW_ETCHED_IN))
+				| (CHECK_DETAIL(detail, "cellradio") && (shadow_type == GTK_SHADOW_ETCHED_IN));
+}
+
 /***********************************************
  * option_menu_get_props -
  *  
@@ -258,7 +269,7 @@ ge_option_menu_get_props (GtkWidget * widget,
   GtkRequisition *tmp_size = NULL;
   GtkBorder *tmp_spacing = NULL;
  
-  if ((widget) && IS_OPTION_MENU(widget))
+  if ((widget) && GE_IS_OPTION_MENU(widget))
     gtk_widget_style_get (widget,
 			  "indicator_size", &tmp_size,
 			  "indicator_spacing", &tmp_spacing, NULL);
@@ -284,9 +295,10 @@ void
 ge_button_get_default_border (GtkWidget *widget, 
                               GtkBorder *border)
 {
+	GtkBorder default_border = {1, 1, 1, 1};
 	GtkBorder *tmp_border = NULL;
 	
-	if (widget && IS_BUTTON (widget))
+	if (widget && GE_IS_BUTTON (widget))
 		gtk_widget_style_get (widget, "default-border", &tmp_border, NULL);
 
 	if (tmp_border)
@@ -296,7 +308,7 @@ ge_button_get_default_border (GtkWidget *widget,
 	}
 	else
 	{
-		*border = (GtkBorder){1, 1, 1, 1};
+		*border = default_border;
 	}
 }
 
@@ -306,7 +318,7 @@ ge_widget_is_ltr (GtkWidget *widget)
 {
 	GtkTextDirection dir = GTK_TEXT_DIR_NONE;
 	
-	if (GTK_IS_WIDGET (widget))
+	if (GE_IS_WIDGET (widget))
 		dir = gtk_widget_get_direction (widget);
 
 	if (dir == GTK_TEXT_DIR_NONE)
